ZEN_LINES = [
    "优美胜于丑陋。",
    "明确胜于含糊。",
    "简洁胜于复杂。",
    "复杂胜于繁琐。",
    "扁平胜于嵌套。",
    "稀疏胜于稠密。",
    "可读性很重要！",
    "特殊情况不足以破坏规则。",
    "虽然实用性胜过纯粹性。",
    "错误不应该悄无声息地通过，",
    "除非明确被沉默。",
    "面对模糊性，宁可拒绝猜测。",
    "应该只有一种明显且最好只有一种方式去做这件事。",
    "尽管那种方式以前可能不是那么明显。",
    "现在比永远好。",
    "虽然永远不应牺牲可读性来追求速度。",
    "如果实现简单且易读，优于复杂但快速的实现。",
    "命名空间是一种绝妙的主意——让我们多用它们吧！",
]